@@ -48,7 +48,7 @@ void destroy(void* v)
   t->~T();
 }
 
-int main( int argc, char *argv [])
+int main()
 {
   std::set_terminate(my_terminate);
   {
